==> slayersbeasts-fabric-1.21.1-5.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/model/MantisModel.java <==
package net.invictusslayer.slayersbeasts.client.model;

import net.invictusslayer.slayersbeasts.SlayersBeasts;
import net.invictusslayer.slayersbeasts.client.animation.MantisAnimation;
import net.invictusslayer.slayersbeasts.world.entity.Mantis;
import net.minecraft.class_2960;
import net.minecraft.class_3532;
import net.minecraft.class_5597;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class MantisModel<T extends Mantis> extends class_5597<T> {
	public static final class_5601 LAYER_LOCATION = new class_5601(class_2960.method_60655(SlayersBeasts.MOD_ID, "mantis_model"), "main");
	private final class_630 root;
	private final class_630 head;

	public MantisModel(class_630 root) {
		this.root = root;
		this.head = root.method_32086("body").method_32086("head");
	}

	public class_630 method_32008() {
		return root;
	}

	public void setupAnim(T entity, float limbSwing, float limbSwingAmount, float ageInTicks, float netHeadYaw, float headPitch) {
		root.method_32088().forEach(class_630::method_41923);
		head.field_3654 += class_3532.method_15363(headPitch, -22.5F, 22.5F) * class_3532.field_29844 / 180F;
		head.field_3675 += class_3532.method_15363(netHeadYaw, -32.5F, 32.5F) * class_3532.field_29844 / 180F;
		method_43782(entity.flapAnimationState, MantisAnimation.FLAP, ageInTicks, 10);
		method_43782(entity.strikeAnimationState, MantisAnimation.STRIKE, ageInTicks, 8);
		if (entity.isScuttling()) {
			method_48741(MantisAnimation.SCUTTLE, limbSwing, limbSwingAmount, 10, 10);
		} else {
			method_48741(MantisAnimation.WALK, limbSwing, limbSwingAmount, 10, 10);
		}
	}

	public static class_5607 createBodyLayer() {
		class_5609 meshdefinition = new class_5609();
		class_5610 partdefinition = meshdefinition.method_32111();

		class_5610 body = partdefinition.method_32117("body", class_5606.method_32108().method_32101(0, 0).method_32098(-2.5F, -1.0F, -17.0F, 5.0F, 3.0F, 28.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 3.0F, 0.0F, -0.48F, 0.0F, 0.0F));

		class_5610 head = body.method_32117("head", class_5606.method_32108().method_32101(100, 94).method_32098(-3.5F, -1.0F, -4.0F, 7.0F, 6.0F, 4.0F, new class_5605(0.0F))
				.method_32101(102, 84).method_32098(-4.5F, -2.0F, -5.0F, 3.0F, 5.0F, 4.0F, new class_5605(0.0F))
				.method_32101(88, 104).method_32098(1.5F, -2.0F, -5.0F, 3.0F, 5.0F, 4.0F, new class_5605(0.0F))
				.method_32101(0, 107).method_32098(-2.5F, 5.0F, -3.5F, 5.0F, 3.0F, 3.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -0.5F, -16.0F, 0.3054F, 0.0F, 0.0F));

		class_5610 cube_r1 = head.method_32117("cube_r1", class_5606.method_32108().method_32101(76, 72).method_32098(-0.5F, -9.5F, -12.0F, 0.0F, 9.0F, 13.0F, new class_5605(0.0F)), class_5603.method_32091(1.5F, -0.5F, -2.0F, 0.0F, -0.1745F, 0.0F));

		class_5610 cube_r2 = head.method_32117("cube_r2", class_5606.method_32108().method_32101(76, 72).method_32098(0.5F, -9.5F, -12.0F, 0.0F, 9.0F, 13.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, -0.5F, -2.0F, 0.0F, 0.1745F, 0.0F));

		class_5610 jaw_left = head.method_32117("jaw_left", class_5606.method_32108().method_32101(82, 31).method_32098(0.0F, -1.0F, 0.0F, 4.0F, 5.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 9.0F, -2.0F, 0.0F, 0.0F, -0.1745F));

		class_5610 jaw_right = head.method_32117("jaw_right", class_5606.method_32108().method_32101(82, 26).method_32098(-4.0F, -1.0F, 0.0F, 4.0F, 5.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 9.0F, -2.0F, 0.0F, 0.0F, 0.1745F));

		class_5610 abdomen = body.method_32117("abdomen", class_5606.method_32108().method_32101(0, 31).method_32098(-5.0F, -4.0F, 0.0F, 10.0F, 5.0F, 21.0F, new class_5605(0.0F))
				.method_32101(76, 94).method_32098(-4.0F, -4.0F, 21.0F, 8.0F, 4.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 2.0F, 11.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 wing_left_upper = body.method_32117("wing_left_upper", class_5606.method_32108().method_32101(56, 102).method_32098(-0.5F, -40.0F, -1.0F, 1.0F, 22.0F, 2.0F, new class_5605(0.0F))
				.method_32101(46, 102).method_32098(-0.5F, -18.0F, -1.0F, 1.0F, 18.0F, 4.0F, new class_5605(0.0F))
				.method_32101(0, 57).method_32098(0.0F, -42.0F, -1.0F, 0.0F, 40.0F, 10.0F, new class_5605(0.0F)), class_5603.method_32091(1.0F, 1.0F, -2.0F, -1.4399F, 0.3491F, -1.2217F));

		class_5610 wing_left_lower = body.method_32117("wing_left_lower", class_5606.method_32108().method_32101(40, 102).method_32098(-1.0F, -24.0F, -1.0F, 1.0F, 24.0F, 2.0F, new class_5605(0.0F))
				.method_32101(40, 57).method_32098(-0.5F, -38.0F, -1.0F, 0.0F, 36.0F, 9.0F, new class_5605(0.0F)), class_5603.method_32091(1.0F, 1.0F, 1.0F, -1.4399F, 0.3491F, -1.3526F));

		class_5610 lw1 = wing_left_lower.method_32117("lw1", class_5606.method_32108().method_32101(66, 0).method_32098(0.0F, -32.0F, 1.0F, 0.0F, 28.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(-0.5F, 0.0F, 0.0F, 0.0436F, 0.0F, 0.0F));

		class_5610 lw2 = lw1.method_32117("lw2", class_5606.method_32108().method_32101(82, 0).method_32098(0.0F, -24.0F, 2.0F, 0.0F, 16.0F, 10.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, 4.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 leg_left_front = body.method_32117("leg_left_front", class_5606.method_32108().method_32101(102, 104).method_32098(-1.0F, -2.0F, -1.0F, 2.0F, 12.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(1.5F, 2.0F, -9.0F, 0.3491F, -0.3491F, -0.3054F));

		class_5610 l11 = leg_left_front.method_32117("l11", class_5606.method_32108().method_32101(92, 52).method_32098(-0.999F, -1.0F, -11.0F, 2.0F, 4.0F, 12.0F, new class_5605(0.0F))
				.method_32101(102, 0).method_32098(0.0F, 3.0F, -8.5F, 0.0F, 2.0F, 10.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 10.0F, 0.0F, -1.1781F, 0.0F, 0.0F));

		class_5610 l12 = l11.method_32117("l12", class_5606.method_32108().method_32101(32, 107).method_32098(-1.0F, 0.0F, -1.0F, 2.0F, 9.0F, 2.0F, new class_5605(0.0F))
				.method_32101(70, 36).method_32098(0.001F, 4.5F, 0.0F, 0.0F, 14.0F, 2.0F, new class_5605(0.0F))
				.method_32101(70, 109).method_32098(-0.5F, 9.0F, -1.0F, 1.0F, 7.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 2.0F, -10.0F, 0.9163F, 0.0F, 0.0F));

		class_5610 leg_left_mid = body.method_32117("leg_left_mid", class_5606.method_32108().method_32101(16, 107).method_32098(-1.0F, -2.0F, -1.0F, 2.0F, 10.0F, 2.0F, new class_5605(0.0F))
				.method_32101(92, 68).method_32098(1.001F, 6.0F, -1.0F, 9.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(102, 16).method_32098(-0.999F, 8.0F, 0.0F, 9.0F, 7.0F, 0.0F, new class_5605(0.0F))
				.method_32101(62, 36).method_32098(8.001F, 8.0F, -1.0F, 2.0F, 17.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(1.5F, 2.0F, -2.0F, 0.3491F, 0.5236F, -0.1309F));

		class_5610 leg_left_hind = body.method_32117("leg_left_hind", class_5606.method_32108().method_32101(24, 107).method_32098(-1.0F, -2.0F, -1.0F, 2.0F, 10.0F, 2.0F, new class_5605(0.0F))
				.method_32101(102, 12).method_32098(1.001F, 6.0F, -1.0F, 9.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(102, 72).method_32098(-0.999F, 8.0F, 0.0F, 9.0F, 6.0F, 0.0F, new class_5605(0.0F))
				.method_32101(62, 102).method_32098(8.001F, 8.0F, -1.0F, 2.0F, 17.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(1.5F, 2.0F, 2.0F, 0.6981F, -0.2182F, -0.6545F));

		class_5610 wing_right_upper = body.method_32117("wing_right_upper", class_5606.method_32108().method_32101(56, 102).method_32098(-0.5F, -40.0F, -1.0F, 1.0F, 22.0F, 2.0F, new class_5605(0.0F))
				.method_32101(46, 102).method_32098(-0.5F, -18.0F, -1.0F, 1.0F, 18.0F, 4.0F, new class_5605(0.0F))
				.method_32101(20, 57).method_32098(0.0F, -42.0F, -1.0F, 0.0F, 40.0F, 10.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, 1.0F, -2.0F, -1.4399F, -0.3491F, 1.2217F));

		class_5610 wing_right_lower = body.method_32117("wing_right_lower", class_5606.method_32108().method_32101(40, 102).method_32098(0.0F, -24.0F, -1.0F, 1.0F, 24.0F, 2.0F, new class_5605(0.0F))
				.method_32101(58, 57).method_32098(0.5F, -38.0F, -1.0F, 0.0F, 36.0F, 9.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, 1.0F, 1.0F, -1.4399F, -0.3491F, 1.3526F));

		class_5610 rw1 = wing_right_lower.method_32117("rw1", class_5606.method_32108().method_32101(76, 36).method_32098(-1.0F, -32.0F, 1.0F, 0.0F, 28.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(1.5F, 0.0F, 0.0F, 0.0436F, 0.0F, 0.0F));

		class_5610 rw2 = rw1.method_32117("rw2", class_5606.method_32108().method_32101(92, 26).method_32098(-1.0F, -24.0F, 2.0F, 0.0F, 16.0F, 10.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, 4.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 leg_right_front = body.method_32117("leg_right_front", class_5606.method_32108().method_32101(102, 104).method_32098(-1.0F, -2.0F, -1.0F, 2.0F, 12.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, 2.0F, -9.0F, 0.3491F, 0.3491F, 0.3054F));

		class_5610 r11 = leg_right_front.method_32117("r11", class_5606.method_32108().method_32101(92, 52).method_32098(-1.001F, -1.0F, -11.0F, 2.0F, 4.0F, 12.0F, new class_5605(0.0F))
				.method_32101(102, 0).method_32098(0.0F, 3.0F, -8.5F, 0.0F, 2.0F, 10.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 10.0F, 0.0F, -1.1781F, 0.0F, 0.0F));

		class_5610 r12 = r11.method_32117("r12", class_5606.method_32108().method_32101(32, 107).method_32098(-1.0F, 0.0F, -1.0F, 2.0F, 9.0F, 2.0F, new class_5605(0.0F))
				.method_32101(70, 36).method_32098(-0.001F, 4.5F, 0.0F, 0.0F, 14.0F, 2.0F, new class_5605(0.0F))
				.method_32101(70, 109).method_32098(-0.5F, 9.0F, -1.0F, 1.0F, 7.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 2.0F, -10.0F, 0.9163F, 0.0F, 0.0F));

		class_5610 leg_right_mid = body.method_32117("leg_right_mid", class_5606.method_32108().method_32101(16, 107).method_32098(-1.0F, -2.0F, -1.0F, 2.0F, 10.0F, 2.0F, new class_5605(0.0F))
				.method_32101(92, 68).method_32098(-9.999F, 6.0F, -1.0F, 9.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(70, 102).method_32098(-7.999F, 8.0F, 0.0F, 9.0F, 7.0F, 0.0F, new class_5605(0.0F))
				.method_32101(62, 36).method_32098(-9.999F, 8.0F, -1.0F, 2.0F, 17.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, 2.0F, -2.0F, 0.3491F, -0.5236F, 0.1309F));

		class_5610 leg_right_hind = body.method_32117("leg_right_hind", class_5606.method_32108().method_32101(24, 107).method_32098(-1.0F, -2.0F, -1.0F, 2.0F, 10.0F, 2.0F, new class_5605(0.0F))
				.method_32101(102, 12).method_32098(-9.999F, 6.0F, -1.0F, 9.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(102, 78).method_32098(-7.999F, 8.0F, 0.0F, 9.0F, 6.0F, 0.0F, new class_5605(0.0F))
				.method_32101(62, 102).method_32098(-9.999F, 8.0F, -1.0F, 2.0F, 17.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, 2.0F, 2.0F, 0.6981F, 0.2182F, 0.6545F));

		return class_5607.method_32110(meshdefinition, 128, 128);
	}
}

==> slayersbeasts-fabric-1.21.4-6.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/model/MantisModel.java <==
package net.invictusslayer.slayersbeasts.client.model;

import net.invictusslayer.slayersbeasts.SlayersBeasts;
import net.invictusslayer.slayersbeasts.client.animation.MantisAnimation;
import net.invictusslayer.slayersbeasts.client.state.MantisRenderState;
import net.minecraft.class_2960;
import net.minecraft.class_3532;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_583;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class MantisModel extends class_583<MantisRenderState> {
	public static final class_5601 LAYER_LOCATION = new class_5601(class_2960.method_60655(SlayersBeasts.MOD_ID, "mantis_model"), "main");
	private final class_630 head;

	public MantisModel(class_630 root) {
		super(root);
		head = root.method_32086("body").method_32086("head");
	}

	public void setupAnim(MantisRenderState state) {
		super.method_2819(state);
		head.field_3654 += class_3532.method_15363(state.field_53448, -22.5F, 22.5F) * class_3532.field_29844 / 180F;
		head.field_3675 += class_3532.method_15363(state.field_53447, -32.5F, 32.5F) * class_3532.field_29844 / 180F;
		method_62099(state.flapAnimationState, MantisAnimation.FLAP, state.field_53328, 10);
		method_62099(state.strikeAnimationState, MantisAnimation.STRIKE, state.field_53328, 8);
		if (state.isScuttling) {
			method_62102(MantisAnimation.SCUTTLE, state.field_53450, state.field_53451, 10, 10);
		} else {
			method_62102(MantisAnimation.WALK, state.field_53450, state.field_53451, 10, 10);
		}
	}

	public static class_5607 createBodyLayer() {
		class_5609 meshdefinition = new class_5609();
		class_5610 partdefinition = meshdefinition.method_32111();

		class_5610 body = partdefinition.method_32117("body", class_5606.method_32108().method_32101(0, 0).method_32098(-2.5F, -1.0F, -17.0F, 5.0F, 3.0F, 28.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 3.0F, 0.0F, -0.48F, 0.0F, 0.0F));

		class_5610 head = body.method_32117("head", class_5606.method_32108().method_32101(100, 94).method_32098(-3.5F, -1.0F, -4.0F, 7.0F, 6.0F, 4.0F, new class_5605(0.0F))
				.method_32101(102, 84).method_32098(-4.5F, -2.0F, -5.0F, 3.0F, 5.0F, 4.0F, new class_5605(0.0F))
				.method_32101(88, 104).method_32098(1.5F, -2.0F, -5.0F, 3.0F, 5.0F, 4.0F, new class_5605(0.0F))
				.method_32101(0, 107).method_32098(-2.5F, 5.0F, -3.5F, 5.0F, 3.0F, 3.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -0.5F, -16.0F, 0.3054F, 0.0F, 0.0F));

		class_5610 cube_r1 = head.method_32117("cube_r1", class_5606.method_32108().method_32101(76, 72).method_32098(-0.5F, -9.5F, -12.0F, 0.0F, 9.0F, 13.0F, new class_5605(0.0F)), class_5603.method_32091(1.5F, -0.5F, -2.0F, 0.0F, -0.1745F, 0.0F));

		class_5610 cube_r2 = head.method_32117("cube_r2", class_5606.method_32108().method_32101(76, 72).method_32098(0.5F, -9.5F, -12.0F, 0.0F, 9.0F, 13.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, -0.5F, -2.0F, 0.0F, 0.1745F, 0.0F));

		class_5610 jaw_left = head.method_32117("jaw_left", class_5606.method_32108().method_32101(82, 31).method_32098(0.0F, -1.0F, 0.0F, 4.0F, 5.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 9.0F, -2.0F, 0.0F, 0.0F, -0.1745F));

		class_5610 jaw_right = head.method_32117("jaw_right", class_5606.method_32108().method_32101(82, 26).method_32098(-4.0F, -1.0F, 0.0F, 4.0F, 5.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 9.0F, -2.0F, 0.0F, 0.0F, 0.1745F));

		class_5610 abdomen = body.method_32117("abdomen", class_5606.method_32108().method_32101(0, 31).method_32098(-5.0F, -4.0F, 0.0F, 10.0F, 5.0F, 21.0F, new class_5605(0.0F))
				.method_32101(76, 94).method_32098(-4.0F, -4.0F, 21.0F, 8.0F, 4.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 2.0F, 11.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 wing_left_upper = body.method_32117("wing_left_upper", class_5606.method_32108().method_32101(56, 102).method_32098(-0.5F, -40.0F, -1.0F, 1.0F, 22.0F, 2.0F, new class_5605(0.0F))
				.method_32101(46, 102).method_32098(-0.5F, -18.0F, -1.0F, 1.0F, 18.0F, 4.0F, new class_5605(0.0F))
				.method_32101(0, 57).method_32098(0.0F, -42.0F, -1.0F, 0.0F, 40.0F, 10.0F, new class_5605(0.0F)), class_5603.method_32091(1.0F, 1.0F, -2.0F, -1.4399F, 0.3491F, -1.2217F));

		class_5610 wing_left_lower = body.method_32117("wing_left_lower", class_5606.method_32108().method_32101(40, 102).method_32098(-1.0F, -24.0F, -1.0F, 1.0F, 24.0F, 2.0F, new class_5605(0.0F))
				.method_32101(40, 57).method_32098(-0.5F, -38.0F, -1.0F, 0.0F, 36.0F, 9.0F, new class_5605(0.0F)), class_5603.method_32091(1.0F, 1.0F, 1.0F, -1.4399F, 0.3491F, -1.3526F));

		class_5610 lw1 = wing_left_lower.method_32117("lw1", class_5606.method_32108().method_32101(66, 0).method_32098(0.0F, -32.0F, 1.0F, 0.0F, 28.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(-0.5F, 0.0F, 0.0F, 0.0436F, 0.0F, 0.0F));

		class_5610 lw2 = lw1.method_32117("lw2", class_5606.method_32108().method_32101(82, 0).method_32098(0.0F, -24.0F, 2.0F, 0.0F, 16.0F, 10.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, 4.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 leg_left_front = body.method_32117("leg_left_front", class_5606.method_32108().method_32101(102, 104).method_32098(-1.0F, -2.0F, -1.0F, 2.0F, 12.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(1.5F, 2.0F, -9.0F, 0.3491F, -0.3491F, -0.3054F));

		class_5610 l11 = leg_left_front.method_32117("l11", class_5606.method_32108().method_32101(92, 52).method_32098(-0.999F, -1.0F, -11.0F, 2.0F, 4.0F, 12.0F, new class_5605(0.0F))
				.method_32101(102, 0).method_32098(0.0F, 3.0F, -8.5F, 0.0F, 2.0F, 10.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 10.0F, 0.0F, -1.1781F, 0.0F, 0.0F));

		class_5610 l12 = l11.method_32117("l12", class_5606.method_32108().method_32101(32, 107).method_32098(-1.0F, 0.0F, -1.0F, 2.0F, 9.0F, 2.0F, new class_5605(0.0F))
				.method_32101(70, 36).method_32098(0.001F, 4.5F, 0.0F, 0.0F, 14.0F, 2.0F, new class_5605(0.0F))
				.method_32101(70, 109).method_32098(-0.5F, 9.0F, -1.0F, 1.0F, 7.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 2.0F, -10.0F, 0.9163F, 0.0F, 0.0F));

		class_5610 leg_left_mid = body.method_32117("leg_left_mid", class_5606.method_32108().method_32101(16, 107).method_32098(-1.0F, -2.0F, -1.0F, 2.0F, 10.0F, 2.0F, new class_5605(0.0F))
				.method_32101(92, 68).method_32098(1.001F, 6.0F, -1.0F, 9.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(102, 16).method_32098(-0.999F, 8.0F, 0.0F, 9.0F, 7.0F, 0.0F, new class_5605(0.0F))
				.method_32101(62, 36).method_32098(8.001F, 8.0F, -1.0F, 2.0F, 17.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(1.5F, 2.0F, -2.0F, 0.3491F, 0.5236F, -0.1309F));

		class_5610 leg_left_hind = body.method_32117("leg_left_hind", class_5606.method_32108().method_32101(24, 107).method_32098(-1.0F, -2.0F, -1.0F, 2.0F, 10.0F, 2.0F, new class_5605(0.0F))
				.method_32101(102, 12).method_32098(1.001F, 6.0F, -1.0F, 9.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(102, 72).method_32098(-0.999F, 8.0F, 0.0F, 9.0F, 6.0F, 0.0F, new class_5605(0.0F))
				.method_32101(62, 102).method_32098(8.001F, 8.0F, -1.0F, 2.0F, 17.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(1.5F, 2.0F, 2.0F, 0.6981F, -0.2182F, -0.6545F));

		class_5610 wing_right_upper = body.method_32117("wing_right_upper", class_5606.method_32108().method_32101(56, 102).method_32098(-0.5F, -40.0F, -1.0F, 1.0F, 22.0F, 2.0F, new class_5605(0.0F))
				.method_32101(46, 102).method_32098(-0.5F, -18.0F, -1.0F, 1.0F, 18.0F, 4.0F, new class_5605(0.0F))
				.method_32101(20, 57).method_32098(0.0F, -42.0F, -1.0F, 0.0F, 40.0F, 10.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, 1.0F, -2.0F, -1.4399F, -0.3491F, 1.2217F));

		class_5610 wing_right_lower = body.method_32117("wing_right_lower", class_5606.method_32108().method_32101(40, 102).method_32098(0.0F, -24.0F, -1.0F, 1.0F, 24.0F, 2.0F, new class_5605(0.0F))
				.method_32101(58, 57).method_32098(0.5F, -38.0F, -1.0F, 0.0F, 36.0F, 9.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, 1.0F, 1.0F, -1.4399F, -0.3491F, 1.3526F));

		class_5610 rw1 = wing_right_lower.method_32117("rw1", class_5606.method_32108().method_32101(76, 36).method_32098(-1.0F, -32.0F, 1.0F, 0.0F, 28.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(1.5F, 0.0F, 0.0F, 0.0436F, 0.0F, 0.0F));

		class_5610 rw2 = rw1.method_32117("rw2", class_5606.method_32108().method_32101(92, 26).method_32098(-1.0F, -24.0F, 2.0F, 0.0F, 16.0F, 10.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, 4.0F, 0.3491F, 0.0F, 0.0F));

		class_5610 leg_right_front = body.method_32117("leg_right_front", class_5606.method_32108().method_32101(102, 104).method_32098(-1.0F, -2.0F, -1.0F, 2.0F, 12.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, 2.0F, -9.0F, 0.3491F, 0.3491F, 0.3054F));

		class_5610 r11 = leg_right_front.method_32117("r11", class_5606.method_32108().method_32101(92, 52).method_32098(-1.001F, -1.0F, -11.0F, 2.0F, 4.0F, 12.0F, new class_5605(0.0F))
				.method_32101(102, 0).method_32098(0.0F, 3.0F, -8.5F, 0.0F, 2.0F, 10.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 10.0F, 0.0F, -1.1781F, 0.0F, 0.0F));

		class_5610 r12 = r11.method_32117("r12", class_5606.method_32108().method_32101(32, 107).method_32098(-1.0F, 0.0F, -1.0F, 2.0F, 9.0F, 2.0F, new class_5605(0.0F))
				.method_32101(70, 36).method_32098(-0.001F, 4.5F, 0.0F, 0.0F, 14.0F, 2.0F, new class_5605(0.0F))
				.method_32101(70, 109).method_32098(-0.5F, 9.0F, -1.0F, 1.0F, 7.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 2.0F, -10.0F, 0.9163F, 0.0F, 0.0F));

		class_5610 leg_right_mid = body.method_32117("leg_right_mid", class_5606.method_32108().method_32101(16, 107).method_32098(-1.0F, -2.0F, -1.0F, 2.0F, 10.0F, 2.0F, new class_5605(0.0F))
				.method_32101(92, 68).method_32098(-9.999F, 6.0F, -1.0F, 9.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(70, 102).method_32098(-7.999F, 8.0F, 0.0F, 9.0F, 7.0F, 0.0F, new class_5605(0.0F))
				.method_32101(62, 36).method_32098(-9.999F, 8.0F, -1.0F, 2.0F, 17.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, 2.0F, -2.0F, 0.3491F, -0.5236F, 0.1309F));

		class_5610 leg_right_hind = body.method_32117("leg_right_hind", class_5606.method_32108().method_32101(24, 107).method_32098(-1.0F, -2.0F, -1.0F, 2.0F, 10.0F, 2.0F, new class_5605(0.0F))
				.method_32101(102, 12).method_32098(-9.999F, 6.0F, -1.0F, 9.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(102, 78).method_32098(-7.999F, 8.0F, 0.0F, 9.0F, 6.0F, 0.0F, new class_5605(0.0F))
				.method_32101(62, 102).method_32098(-9.999F, 8.0F, -1.0F, 2.0F, 17.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, 2.0F, 2.0F, 0.6981F, 0.2182F, 0.6545F));

		return class_5607.method_32110(meshdefinition, 128, 128);
	}
}
